@@ -217,19 +217,22 @@ class act_daily
                 'tpc.id as ref_topic,'.
                 'tpc.topic as topic,'.
                 $date.' as modify,'.
-                'count(com.id) as ct '.
+                'count(cmt.id) as ct '.
             'FROM '.
+                DB_PREFIX.'com_topic tpc '.
+                    'LEFT JOIN '.DB_PREFIX.'com_comment cmt '.
+                    'ON tpc.id = cmt.ref_topic,'.
+                DB_PREFIX.'act_account act,'.
                 DB_PREFIX.'com_community com,'.
-                DB_PREFIX.'com_names nam,'.
-                DB_PREFIX.'com_topic tpc,'.
-                DB_PREFIX.'com_comment com '.
+                DB_PREFIX.'com_names nam '.
             'WHERE '.
+                'act.id = tpc.ref_account AND '.
+                'act.avail = '.AVAIL_ENABLE.' AND '.
                 'com.id = nam.ref_community AND '.
                 'com.id = tpc.ref_community AND '.
-                'tpc.id = com.ref_topic AND '.
                 'com.avail = '.AVAIL_ENABLE.' AND '.
-                'nam.ref_account = '.$this->ref_account.' AND '.
                 $format." >= '".$this->date."' AND ".
+                'nam.ref_account = '.$this->ref_account.' AND '.
                 'nam.status != '.STATUS_COMMUNITY_REFUSAL.' AND '.
                 'nam.status != '.STATUS_COMMUNITY_REQUEST.' '.
             'GROUP BY '.
@@ -237,7 +240,7 @@ class act_daily
                 'tpc.id,'.
                 'nam.id '.
             'ORDER BY '.
-                'com.modify DESC '.
+                'tpc.modify DESC '.
             'LIMIT 5';
         $stmt = $this->objdb->prepare($sql); 
         $stmt->execute(); 
@@ -261,6 +264,7 @@ class act_daily
     {
         $date = sql_query::dateFormat('ent.regist_date','%m月 %d日 ');
         $format = sql_query::dateFormat('ent.regist_date','%Y%m%d');
+
         $sql=
             'SELECT '.
                 'ent.id as ref_entry,'.
@@ -276,19 +280,16 @@ class act_daily
                 DB_PREFIX.'fri_friends fri '.
             'WHERE '.
                 'act.id = pro.ref_account AND '.
-                'act.id != '.$this->ref_account .' AND '.
+                'act.id != '.$this->ref_account.' AND '.
                 'act.id = dia.ref_account AND '.
                 'dia.id = ent.ref_diary AND '.
+                'act.id = ent.ref_account AND '.
                 $format." >= '".$this->date."' AND ".
                 'act.avail = '.AVAIL_ENABLE.' AND '.
                 'fri.avail = '.AVAIL_ENABLE.' AND '.
                 'fri.status = '.STATUS_FRIEND_CONNECT.' AND '.
-                '('.
-                    '(fri.ref_account = act.id OR '.
-                    'fri.ref_friend = act.id) AND '.
-                    '(fri.ref_account = '.$this->ref_account .' OR '.
-                    'fri.ref_friend = '.$this->ref_account.')'.
-                ') '.
+                'fri.ref_account = '.$this->ref_account.' AND '.
+                'fri.ref_friend = act.id '.
             'ORDER BY '.
                 'ent.regist_date DESC '.
             'LIMIT 5';
