@@ -21,6 +21,8 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/02/02] 最新情報表示期間定義を追加
+ -      [2007/02/02] 日記コメント定義を追加
  -      [2007/01/29] 日記のフォーマット定義を追加
  -      [2007/01/08] PathInfo未使用時用のFormメソッドの定義を追加
  -      [2006/09/29] タイムアウト時間設定 WAP_TIME_LIMIT を追加
@@ -329,6 +331,13 @@ define('POSITION_SPONSOR_SIDE',   3);                               // 側面部
 define('DIARY_FORMAT_PLAIN', 1);                                    // デフォルト
 define('DIARY_FORMAT_HTML',  2);                                    // HTML形式
 
+/* 日記のコメント */
+define('COMMENT_FLAG_UNREAD',1);                                    // 未読メッセージ
+define('COMMENT_FLAG_READ',  2);                                    // 既読メッセージ
+
+/* 表示期間 */
+define('TERM_MYHOME_NEWS', '-2 weeks');                             // Myホームの最新リストの期間
+
 /* ---------------------------------------- */
 /* RKTフレームワーク用定義 */
 define('RKT_SEED',WAP_PASS_SEED);                                   // 暗号等に使われる種
