@@ -21,6 +21,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/01/26] ユーザーなりすまし機能追加
  -      [2006/08/29] 整形表示のエラー修正
  -      [2006/08/04] 作成
  - ======================================================================== */
@@ -62,6 +63,12 @@ class webapp extends WAP_admin
         $this->setSafety('id');
         $this->Assign('id', $this->id);
 
+        /* ユーザーになりすます */
+        if ($this->spoofing()){
+            header('Location: '.HTTP_ACTION.'private/home/home/');
+            exit();
+        }
+
         $this->set_relation();
         $this->set_friend_number();
         $this->set_photo();
@@ -72,6 +79,29 @@ class webapp extends WAP_admin
         $this->set_community_number();
     }
 
+    /**
+     * ユーザーになりすます
+     *
+     * @access public
+     * @return void
+     */
+    function spoofing()
+    {
+        if (empty($_POST['spoofing'])){
+            return false;
+        }
+
+        $func = array(RKT_ACCOUNT_CLASS, 'getInstance');
+        $account = call_user_func($func);
+        $_SESSION['administer'] = $account;
+
+
+        $spoofing = new account();
+        $spoofing->setInfo($this->id);
+        
+        return true;
+    }
+
     /**
      * 招待元の友達設定
      *
