@@ -74,6 +74,10 @@ class webapp extends WAP_admin
             header('Location: '.HTTP_ACTION.'admin/design/design/complete/');
             exit();
         }
+
+        if (preg_match('/complete/i',$_SERVER['REQUEST_URI'])){
+            $this->Assign('complete', true);
+        }
         
         $this->set_theme();
     }
