@@ -21,6 +21,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/02/03] 日記コメント未読フラグ追加
  -      [2006/08/28] あしあと処理実行部位追加
  -      [2006/07/27] 作成
  - ======================================================================== */
@@ -352,6 +353,7 @@ class webapp extends WAP_friend
         $this->objmnp->setValue('ref_account', $this->account['id']);
         $this->objmnp->setValue('ref_diary', $this->ref_diary);
         $this->objmnp->setValue('ref_entry', $this->id);
+        $this->objmnp->setValue('flag', COMMENT_FLAG_UNREAD);
 
         // 更新しない項目名
         $skip = array(
