@@ -21,6 +21,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/02/03] 日記コメント未読フラグ追加
  -      [2006/07/25] 作成
  - ======================================================================== */
 
@@ -113,6 +114,7 @@ class webapp extends WAP_private
 
         $this->set_picture();
         $this->set_category();
+        $this->update_comment();
         $this->set_comment_num();
         $this->set_comment();
     }
@@ -348,6 +350,7 @@ class webapp extends WAP_private
         $this->objmnp->setValue('ref_account', $this->account['id']);
         $this->objmnp->setValue('ref_diary', $this->ref_diary);
         $this->objmnp->setValue('ref_entry', $this->id);
+        $this->objmnp->setValue('flag', COMMENT_FLAG_READ);
 
         // 更新しない項目名
         $skip = array(
@@ -356,6 +359,25 @@ class webapp extends WAP_private
         return $this->objmnp->execute($this,$skip);
     }
 
+    /**
+     * コメントの更新
+     *
+     * @access private
+     * @return boolean  真偽値
+     */
+    function update_comment()
+    {
+        $sql =
+            'UPDATE '.
+                DB_PREFIX.'dia_comment '.
+            'SET '.
+                'flag = '.COMMENT_FLAG_READ.' '.
+            'WHERE '.
+                'ref_diary = '.$this->ref_diary.' AND '.
+                'ref_entry = '.$this->id;
+        return $this->objdb->exec($sql);
+    }
+
     /**
      * コメントの削除
      *
