@@ -21,11 +21,13 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/01/31] 画像添付の追加
  -      [2006/07/10] 作成
  - ======================================================================== */
 
 /* =-=- モジュール等の読み込み -=-= */
 require_once LIB_DIR.'rkt_manip.php';
+require_once WEBAPP_LIB_DIR.'private/msg_pictures.php';
 require_once WEBAPP_LIB_DIR.'wap_private.php';
 
 /**
@@ -50,12 +52,30 @@ class webapp extends WAP_private
      */
     var $ref_account = 0;
 
+    /**
+     * 送信先メッセージID
+     * @var integer
+     */
+    var $to_message_id = 0;
+
     /**
      * 返信対象メッセージID
      * @var integer
      */
     var $ref_message = 0;
 
+    /**
+     * データ操作オブジェクト
+     * @var object
+     */
+    var $objmnp = null;
+
+    /**
+     * 添付画像操作オブジェクト
+     * @var object
+     */
+    var $objpic = null;
+
     /**
      * 実行処理
      *
@@ -85,12 +105,24 @@ class webapp extends WAP_private
             exit();
         }
 
+        // 添付画像操作クラスの生成
+        $objpic = new msg_pictures($this->id);
+        $objpic->doUpload();
+
         // データ操作クラスの生成
         $this->objmnp = new RKT_manip($this->objdb,  DB_PREFIX.'fri_message');
         $result = $this->do_query();
         if ($result == RKT_MANIP_COMPLETE){
             $this->do_send_message();
+            $this->send_mail();
             $this->update_flag();
+
+            /* 添付画像処理 */
+            $objpic->doDelete(true);
+            $objpic->setFix($id);
+            $objpic->setCopy($this->to_message_id,$this->ref_friend);
+            $objpic->unSetPicture();
+
             header('Location: '.HTTP_ACTION.'private/message/list/'.$this->objmnp->getValue('status').'/');
             exit();
         } elseif($result == RKT_MANIP_VALIDATED) {
@@ -107,6 +139,8 @@ class webapp extends WAP_private
         $this->set_profile();
         $this->set_photo();
         $this->set_default_message();
+
+        $this->Assign('picture', $objpic->getImgInfos());
     }
 
     /**
@@ -368,6 +402,7 @@ class webapp extends WAP_private
         if (empty($_GET['delete'])){
             return false;
         }
+        $this->delete_picture();
 
         $sql =
             'DELETE FROM '.
@@ -378,5 +413,81 @@ class webapp extends WAP_private
         return $this->objdb->exec($sql);
     }
 
+    /**
+     * 添付画像の削除
+     *
+     * @access private
+     * @return boolean
+     */
+    function delete_picture()
+    {
+        $sql=
+            'SELECT '.
+                'id,'.
+                'filename,'.
+                'thumbnail '.
+            'FROM '.
+                DB_PREFIX.'fri_picture '.
+            'WHERE '.
+                'ref_message = '.$this->id.' AND '.
+                'ref_account ='.$this->account['id'];
+        $stmt = $this->objdb->prepare($sql); 
+        $stmt->execute(); 
+        $result = $stmt->fetchAll(PDO_FETCH_ASSOC);
+        if (empty($result)){
+            return false;
+        }
+
+        include_once LIB_DIR.'rkt_blob.php';
+        $objblb = RKT_blob::getInstance(BLOB_DRIVER,BLOB_PARAM);
+        foreach ($result as $value){
+            $objblb->unlink($value['filename']);
+            $objblb->unlink($value['thumbnail']);
+        }
+
+        $sql =
+            'DELETE FROM '.
+                DB_PREFIX.'fri_picture '.
+            'WHERE '.
+                'ref_message = '.$this->id.' AND '.
+                'ref_account ='.$this->account['id'];
+        return $this->objdb->exec($sql);
+    }
+
+    /**
+     * 自動通知メール
+     *
+     * @access private
+     * @return void
+     */
+    function send_mail()
+    {
+        $sql=
+            'SELECT '.
+                'act.email as email,'.
+                'pro.nickname as nickname '.
+            'FROM '.
+                DB_PREFIX.'act_account act,'.
+                DB_PREFIX.'act_profile pro '.
+            'WHERE '.
+                'act.id = pro.ref_account AND '.
+                'act.avail = '.AVAIL_ENABLE.' AND '.
+                'act.id = '.$this->ref_account;
+        $stmt = $this->objdb->prepare($sql); 
+        $stmt->execute(); 
+        $infos = $stmt->fetch(PDO_FETCH_ASSOC);
+        $stmt->closeCursor();
+
+        include_once WEBAPP_LIB_DIR.'sendmail.php';
+
+        $objmail = new sendmail('message');
+
+        $objmail->Assign('user_name', $infos['nickname']);
+        $objmail->Assign('friend', $this->account['nickname']);
+        $objmail->Assign('url', HTTP_ACTION.'private/message/list/');
+
+        $to = sql_query::decrypt($infos['email']);
+        $objmail->send($to);
+    }
 } // webapp
 ?>
