@@ -82,38 +82,38 @@ URLをクリックしてください。
 {$footer}');
 INSERT INTO sns_sys_mailtpl VALUES('7','2006-07-22 05:35:11','entryOK','コミュニティ参加のお知らせ','admin@example.com','rktSNS','こちらは「{$site_name}」事務局です。
 
-{$group}へ{$user_name} さんの参加が承認されました。
+{$community}へ{$user_name} さんの参加が承認されました。
 
 
-{$group} の情報を見るには以下のURLをクリックしてください。
+{$community} の情報を見るには以下のURLをクリックしてください。
 {$url}
 
 {$footer}');
 INSERT INTO sns_sys_mailtpl VALUES('8','2006-07-22 05:35:11','entryNG','コミュニティ参加のお知らせ','admin@example.com','rktSNS','こちらは「{$site_name}」事務局です。
 
-{$group}へ{$user_name} さんの参加を見送る事になりました。
+{$community}へ{$user_name} さんの参加を見送る事になりました。
 
-{$group} の情報を見るには以下のURLをクリックしてください。
+{$community} の情報を見るには以下のURLをクリックしてください。
 {$url}
 
 {$footer}');
 INSERT INTO sns_sys_mailtpl VALUES('9','2006-07-22 05:35:11','change','管理人交代のお知らせ','admin@example.com','rktSNS','こちらは「{$site_name}」事務局です。
 
 {$friend} さんは、{$user_name} さんからの
-{$group}の管理人交代を{$result}されました。
+{$community}の管理人交代を{$result}されました。
 
 
-----------------------{$group}----------------------
+----------------------{$community}----------------------
 {$url}
 
 {$footer}');
 INSERT INTO sns_sys_mailtpl VALUES('10','2006-07-22 05:35:11','change_request','管理人交代の願い','admin@example.com','rktSNS','こちらは「{$site_name}」事務局です。
 
 {$user_name} さんに {$friend} さんからの
-{$group}の管理人交代のお願いがあります。
+{$community}の管理人交代のお願いがあります。
 
 
-{$group} の情報を見るには以下のURLをクリックしてください。
+{$community} の情報を見るには以下のURLをクリックしてください。
 {$url}
 
 認証処理を行うには以下のURLをクリックして認証手続きを
@@ -123,9 +123,9 @@ INSERT INTO sns_sys_mailtpl VALUES('10','2006-07-22 05:35:11','change_request','
 {$footer}');
 INSERT INTO sns_sys_mailtpl VALUES('11','2006-07-22 05:35:11','names_delete','コミュニティ退会のお知らせ','admin@example.com','rktSNS','こちらは「{$site_name}」事務局です。
 
-{$group}から{$user_name} さんが退会されました。
+{$community}から{$user_name} さんが退会されました。
 
-{$group} の情報を見るには以下のURLをクリックしてください。
+{$community} の情報を見るには以下のURLをクリックしてください。
 {$url}
 
 {$footer}');
@@ -171,7 +171,7 @@ INSERT INTO sns_sys_mailtpl VALUES('15','2006-07-22 05:35:11','topic','イベン
 
 イベントの企画者 {$friend} さんからのお知らせです。
 
-グループ名：{$group}
+グループ名：{$community}
 イベント名：{$topic}
 
 
@@ -235,7 +235,7 @@ INSERT INTO sns_sys_mailtpl VALUES('17','2006-07-22 05:35:11','daily','rktSNSニ
 ==================================================
 　　　　　コミュニティ掲示板
 {foreach $topics}
-{$_row.modify} … {$_row.topic}({$_row.ct}) ({$_row.group})
+{$_row.modify} … {$_row.topic}({$_row.ct}) ({$_row.community})
 
 　　　　URL … {$http_action}community/bbs/browse/{$_row.ref_community}/{$_row.ref_topic}/
 
