@@ -20,6 +20,7 @@
 --      yujiro@rakuto.net
 --      http://rakuto.net/rktSNS/
 -- 更新履歴：
+--      [2007/02/02] 日記の未読コメントflagを追加
 --      [2007/01/30] メッセージの添付画像(sns_fri_picture)を追加
 --      [2007/01/21] お友達のお友達名簿を修正
 --      [2007/01/21] お友達の招待名簿を追加
@@ -449,6 +450,7 @@ CREATE TABLE `sns_dia_comment` (
   `ref_diary` int(11) NOT NULL,
   `ref_entry` int(11) NOT NULL,
   `ref_account` int(11),
+  `flag` int(11) default '0',
   `subject` varchar(255) NOT NULL,
   `body` text NOT NULL,
   PRIMARY KEY  (`id`)
@@ -536,8 +538,7 @@ CREATE TABLE `sns_fri_friends` (
   `ref_friend` int(11) NOT NULL,
   `comment` text,
   PRIMARY KEY  (`id`),
-  UNIQUE (`ref_account`,`ref_friend`),
-  UNIQUE (`email_hash`)
+  UNIQUE (`ref_account`,`ref_friend`)
 ) TYPE=MyISAM AUTO_INCREMENT=1;
 
 -- 
@@ -778,6 +779,7 @@ CREATE TABLE `sns_com_community` (
   `topic_flag` int(11) NOT NULL,
   `community` varchar(128) NOT NULL,
   `ref_prefecture` int(11) NOT NULL,
+  `url` varchar(128),
   `publicity` text NOT NULL,
   `total` int(11),
   PRIMARY KEY  (`id`)
@@ -900,8 +902,8 @@ CREATE TABLE `sns_inq_inquire` (
   `url` varchar(128),
   `email` blob,
   `comment` text NOT NULL,
-  `subject` varchar(255) NOT NULL default '',
-  `body` text NOT NULL default '',
+  `subject` varchar(255) NOT NULL,
+  `body` text NOT NULL,
   PRIMARY KEY  (`id`)
 ) TYPE=MyISAM AUTO_INCREMENT=1;
 
