@@ -20,6 +20,7 @@
 --      yujiro@rakuto.net
 --      http://rakuto.net/rktSNS/
 -- 更新履歴：
+--      [2007/02/02] 日記の未読コメントflagを追加
 --      [2007/01/30] メッセージの添付画像(sns_fri_picture)を追加
 --      [2007/01/21] お友達のお友達名簿を修正
 --      [2007/01/21] お友達の招待名簿を追加
@@ -434,6 +435,7 @@ CREATE TABLE 'sns_dia_comment' (
   'ref_diary' integer NOT NULL,
   'ref_entry' integer NOT NULL,
   'ref_account' integer,
+  'flag' integer default '1',  
   'subject' varchar(255) NOT NULL,
   'body' text NOT NULL,
   PRIMARY KEY  ('id')
@@ -763,6 +765,7 @@ CREATE TABLE 'sns_com_community' (
   'topic_flag' integer NOT NULL,
   'community' varchar(128) NOT NULL,
   'ref_prefecture' integer NOT NULL,
+  'url' varchar(128),
   'publicity' text NOT NULL,
   'total' integer,
   PRIMARY KEY  ('id')
@@ -886,8 +889,8 @@ CREATE TABLE 'sns_inq_inquire' (
   'url' varchar(128),
   'email' blob,
   'comment' text NOT NULL,
-  'subject' varchar(255) NOT NULL default '',
-  'body' text NOT NULL default '',
+  'subject' varchar(255) NOT NULL,
+  'body' text NOT NULL,
   PRIMARY KEY  ('id')
 );
 
